@@ -8,8 +8,9 @@ import shlex
 import sys
 import urllib.parse
 from argparse import ArgumentParser, Namespace
+from collections.abc import Iterator
 from pathlib import Path
-from typing import IO, Any, Iterator, List, Tuple, cast
+from typing import IO, Any, cast
 from urllib.request import urlopen
 
 import chardet
@@ -21,18 +22,18 @@ from .util import VCS, get_url_scheme, is_url, url_to_path
 # Matches environment variable-style values in '${MY_VARIABLE_1}' with the variable name consisting of only uppercase
 # letters, digits or the '_' (underscore). This follows the POSIX standard defined in IEEE Std 1003.1, 2013 Edition.
 _ENV_VAR_RE = re.compile(r"(?P<var>\${(?P<name>[A-Z0-9_]+)})")
-_SCHEME_RE = re.compile(r"^(http|https|file):", re.I)
+_SCHEME_RE = re.compile(r"^(http|https|file):", re.IGNORECASE)
 _COMMENT_RE = re.compile(r"(^|\s+)#.*$")
 # https://www.python.org/dev/peps/pep-0508/#extras
 _EXTRA_PATH = re.compile(r"(.*)\[([-._,\sa-zA-Z0-9]*)]")
 _EXTRA_ELEMENT = re.compile(r"[a-zA-Z0-9]*[-._a-zA-Z0-9]")
-ReqFileLines = Iterator[Tuple[int, str]]
+ReqFileLines = Iterator[tuple[int, str]]
 
 DEFAULT_INDEX_URL = "https://pypi.org/simple"
 
 
 class ParsedRequirement:
-    def __init__(self, req: str, options: dict[str, Any], from_file: str, lineno: int) -> None:  # noqa: PLR0912
+    def __init__(self, req: str, options: dict[str, Any], from_file: str, lineno: int) -> None:
         req = req.encode("utf-8").decode("utf-8")
         try:
             self._requirement: Requirement | Path | str = Requirement(req)
@@ -111,7 +112,7 @@ class ParsedRequirement:
 
 
 class ParsedLine:
-    def __init__(  # noqa: PLR0913
+    def __init__(
         self,
         filename: str,
         lineno: int,
@@ -168,7 +169,7 @@ class RequirementsFile:
     @property
     def requirements(self) -> list[ParsedRequirement]:
         self._ensure_requirements_parsed()
-        return cast(List[ParsedRequirement], self._requirements)
+        return cast("list[ParsedRequirement]", self._requirements)
 
     @property
     def _parser(self) -> ArgumentParser:
@@ -484,7 +485,7 @@ class RequirementsFile:
 
 
 __all__ = (
-    "RequirementsFile",
-    "ReqFileLines",
     "ParsedRequirement",
+    "ReqFileLines",
+    "RequirementsFile",
 )
